@@ -36,12 +36,11 @@ impl<'a> GetChannel<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut
-            .replace(Box::pin(self.http.request_bytes(Request::from(
-                Route::GetChannel {
-                    channel_id: self.channel_id.0,
-                },
-            ))));
+        let request = Request::from_route(Route::GetChannel {
+            channel_id: self.channel_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request_bytes(request)));
 
         Ok(())
     }
