@@ -1,6 +1,12 @@
 use crate::request::prelude::*;
 
 /// Delete an invite by its code.
+///
+/// Requires the [`MANAGE_CHANNELS`] permission on the channel this invite
+/// belongs to, or [`MANAGE_GUILD`] to remove any invite across the guild.
+///
+/// [`MANAGE_CHANNELS`]: twilight_model::guild::Permissions::MANAGE_CHANNELS
+/// [`MANAGE_GUILD`]: twilight_model::guild::Permissions::MANAGE_GUILD
 pub struct DeleteInvite<'a> {
     code: String,
     fut: Option<Pending<'a, ()>>,
@@ -19,21 +25,16 @@ impl<'a> DeleteInvite<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        let request = if let Some(reason) = &self.reason {
-            let headers = audit_header(&reason)?;
-            Request::from((
-                headers,
-                Route::DeleteInvite {
-                    code: self.code.clone(),
-                },
-            ))
-        } else {
-            Request::from(Route::DeleteInvite {
-                code: self.code.clone(),
-            })
-        };
+        let mut request = Request::builder(Route::DeleteInvite {
+            code: self.code.clone(),
+        });
 
-        self.fut.replace(Box::pin(self.http.verify(request)));
+        if let Some(reason) = &self.reason {
+            request = request.headers(audit_header(reason)?);
+        }
+
+        self.fut
+            .replace(Box::pin(self.http.verify(request.build())));
 
         Ok(())
     }
