@@ -3,7 +3,11 @@ use twilight_model::{id::ChannelId, invite::Invite};
 
 /// Get the invites for a guild channel.
 ///
-/// This method only works if the channel is of type `GuildChannel`.
+/// Requires the [`MANAGE_CHANNELS`] permission. This method only works if the
+/// channel is of type [`GuildChannel`].
+///
+/// [`MANAGE_CHANNELS`]: twilight_model::guild::Permissions::MANAGE_CHANNELS
+/// [`GuildChannel`]: twilight_model::channel::GuildChannel
 pub struct GetChannelInvites<'a> {
     channel_id: ChannelId,
     fut: Option<Pending<'a, Vec<Invite>>>,
@@ -20,11 +24,11 @@ impl<'a> GetChannelInvites<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from(
-            Route::GetChannelInvites {
-                channel_id: self.channel_id.0,
-            },
-        ))));
+        let request = Request::from_route(Route::GetChannelInvites {
+            channel_id: self.channel_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
