@@ -23,13 +23,12 @@ impl<'a> GetMessage<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut
-            .replace(Box::pin(self.http.request_bytes(Request::from(
-                Route::GetMessage {
-                    channel_id: self.channel_id.0,
-                    message_id: self.message_id.0,
-                },
-            ))));
+        let request = Request::from_route(Route::GetMessage {
+            channel_id: self.channel_id.0,
+            message_id: self.message_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request_bytes(request)));
 
         Ok(())
     }
