@@ -20,12 +20,12 @@ impl<'a> DeleteAllReactions<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.verify(Request::from(
-            Route::DeleteMessageReactions {
-                channel_id: self.channel_id.0,
-                message_id: self.message_id.0,
-            },
-        ))));
+        let request = Request::from_route(Route::DeleteMessageReactions {
+            channel_id: self.channel_id.0,
+            message_id: self.message_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.verify(request)));
 
         Ok(())
     }
