@@ -36,10 +36,11 @@ impl<'a> GetBans<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut
-            .replace(Box::pin(self.http.request(Request::from(Route::GetBans {
-                guild_id: self.guild_id.0,
-            }))));
+        let request = Request::from_route(Route::GetBans {
+            guild_id: self.guild_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
