@@ -2,6 +2,10 @@ use crate::request::prelude::*;
 use twilight_model::{id::GuildId, invite::Invite};
 
 /// Get information about the invites of a guild.
+///
+/// Requires the [`MANAGE_GUILD`] permission.
+///
+/// [`MANAGE_GUILD`]: twilight_model::guild::Permissions::MANAGE_GUILD
 pub struct GetGuildInvites<'a> {
     fut: Option<Pending<'a, Vec<Invite>>>,
     guild_id: GuildId,
@@ -18,11 +22,11 @@ impl<'a> GetGuildInvites<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from(
-            Route::GetGuildInvites {
-                guild_id: self.guild_id.0,
-            },
-        ))));
+        let request = Request::from_route(Route::GetGuildInvites {
+            guild_id: self.guild_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
