@@ -18,11 +18,11 @@ impl<'a> GetGuildWebhooks<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from(
-            Route::GetGuildWebhooks {
-                guild_id: self.guild_id.0,
-            },
-        ))));
+        let request = Request::from_route(Route::GetGuildWebhooks {
+            guild_id: self.guild_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
