@@ -18,12 +18,11 @@ impl<'a> GetGuildWelcomeScreen<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut
-            .replace(Box::pin(self.http.request_bytes(Request::from(
-                Route::GetGuildWelcomeScreen {
-                    guild_id: self.guild_id.0,
-                },
-            ))));
+        let request = Request::from_route(Route::GetGuildWelcomeScreen {
+            guild_id: self.guild_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.request_bytes(request)));
 
         Ok(())
     }
