@@ -5,7 +5,8 @@ use std::{
 };
 use twilight_model::{
     guild::{
-        DefaultMessageNotificationLevel, ExplicitContentFilter, PartialGuild, VerificationLevel,
+        DefaultMessageNotificationLevel, ExplicitContentFilter, PartialGuild, SystemChannelFlags,
+        VerificationLevel,
     },
     id::{ChannelId, GuildId, UserId},
 };
@@ -19,7 +20,7 @@ pub struct UpdateGuildError {
 impl UpdateGuildError {
     /// Immutable reference to the type of error that occurred.
     #[must_use = "retrieving the type has no effect if left unused"]
-    pub fn kind(&self) -> &UpdateGuildErrorType {
+    pub const fn kind(&self) -> &UpdateGuildErrorType {
         &self.kind
     }
 
@@ -74,9 +75,15 @@ struct UpdateGuildFields {
     default_message_notifications: Option<Option<DefaultMessageNotificationLevel>>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
+    discovery_splash: Option<Option<String>>,
+    #[allow(clippy::option_option)]
+    #[serde(skip_serializing_if = "Option::is_none")]
     explicit_content_filter: Option<Option<ExplicitContentFilter>>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
+    features: Option<Option<Vec<String>>>,
+    #[allow(clippy::option_option)]
+    #[serde(skip_serializing_if = "Option::is_none")]
     icon: Option<Option<String>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     name: Option<String>,
@@ -93,6 +100,9 @@ struct UpdateGuildFields {
     system_channel_id: Option<Option<ChannelId>>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
+    system_channel_flags: Option<Option<SystemChannelFlags>>,
+    #[allow(clippy::option_option)]
+    #[serde(skip_serializing_if = "Option::is_none")]
     verification_level: Option<Option<VerificationLevel>>,
     #[allow(clippy::option_option)]
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -170,6 +180,17 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
+    /// Set the guild's discovery splash image.
+    ///
+    /// Requires the guild to have the `DISCOVERABLE` feature enabled.
+    pub fn discovery_splash(mut self, discovery_splash: impl Into<Option<String>>) -> Self {
+        self.fields
+            .discovery_splash
+            .replace(discovery_splash.into());
+
+        self
+    }
+
     /// Set the explicit content filter level.
     pub fn explicit_content_filter(
         mut self,
@@ -182,6 +203,15 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
+    /// Set the enabled features of the guild.
+    pub fn features(mut self, features: impl IntoIterator<Item = String>) -> Self {
+        self.fields
+            .features
+            .replace(Some(features.into_iter().collect()));
+
+        self
+    }
+
     /// Set the icon.
     ///
     /// This must be a Data URI, in the form of `data:image/{type};base64,{data}` where `{type}` is
@@ -257,6 +287,18 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
+    /// Set the guild's [`SystemChannelFlags`].
+    pub fn system_channel_flags(
+        mut self,
+        system_channel_flags: impl Into<Option<SystemChannelFlags>>,
+    ) -> Self {
+        self.fields
+            .system_channel_flags
+            .replace(system_channel_flags.into());
+
+        self
+    }
+
     /// Set the rules channel.
     ///
     /// Requires the guild to be `PUBLIC`. Refer to [the discord docs] for more information.
@@ -310,25 +352,17 @@ impl<'a> UpdateGuild<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        let request = if let Some(reason) = &self.reason {
-            let headers = audit_header(&reason)?;
-            Request::from((
-                crate::json_to_vec(&self.fields).map_err(HttpError::json)?,
-                headers,
-                Route::UpdateGuild {
-                    guild_id: self.guild_id.0,
-                },
-            ))
-        } else {
-            Request::from((
-                crate::json_to_vec(&self.fields).map_err(HttpError::json)?,
-                Route::UpdateGuild {
-                    guild_id: self.guild_id.0,
-                },
-            ))
-        };
+        let mut request = Request::builder(Route::UpdateGuild {
+            guild_id: self.guild_id.0,
+        })
+        .json(&self.fields)?;
 
-        self.fut.replace(Box::pin(self.http.request(request)));
+        if let Some(reason) = &self.reason {
+            request = request.headers(audit_header(reason)?)
+        }
+
+        self.fut
+            .replace(Box::pin(self.http.request(request.build())));
 
         Ok(())
     }
