@@ -36,12 +36,13 @@ impl<'a> UpdateGuildChannelPositions<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.verify(Request::from((
-            crate::json_to_vec(&self.positions).map_err(HttpError::json)?,
-            Route::UpdateGuildChannels {
-                guild_id: self.guild_id.0,
-            },
-        )))));
+        let request = Request::builder(Route::UpdateGuildChannels {
+            guild_id: self.guild_id.0,
+        })
+        .json(&self.positions)?
+        .build();
+
+        self.fut.replace(Box::pin(self.http.verify(request)));
 
         Ok(())
     }
