@@ -55,13 +55,14 @@ impl<'a> UpdateUserVoiceState<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.verify(Request::from((
-            crate::json_to_vec(&self.fields).map_err(HttpError::json)?,
-            Route::UpdateUserVoiceState {
-                guild_id: self.guild_id.0,
-                user_id: self.user_id.0,
-            },
-        )))));
+        let request = Request::builder(Route::UpdateUserVoiceState {
+            guild_id: self.guild_id.0,
+            user_id: self.user_id.0,
+        })
+        .json(&self.fields)?
+        .build();
+
+        self.fut.replace(Box::pin(self.http.verify(request)));
 
         Ok(())
     }
