@@ -22,11 +22,11 @@ impl<'a> GetTemplate<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from(
-            Route::GetTemplate {
-                template_code: self.template_code.clone(),
-            },
-        ))));
+        let request = Request::from_route(Route::GetTemplate {
+            template_code: self.template_code.clone(),
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
