@@ -114,13 +114,14 @@ impl<'a> UpdateTemplate<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from((
-            crate::json_to_vec(&self.fields).map_err(HttpError::json)?,
-            Route::UpdateTemplate {
-                guild_id: self.guild_id.0,
-                template_code: self.template_code.clone(),
-            },
-        )))));
+        let request = Request::builder(Route::UpdateTemplate {
+            guild_id: self.guild_id.0,
+            template_code: self.template_code.clone(),
+        })
+        .json(&self.fields)?
+        .build();
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
