@@ -14,7 +14,7 @@ pub struct GetCurrentUserGuildsError {
 impl GetCurrentUserGuildsError {
     /// Immutable reference to the type of error that occurred.
     #[must_use = "retrieving the type has no effect if left unused"]
-    pub fn kind(&self) -> &GetCurrentUserGuildsErrorType {
+    pub const fn kind(&self) -> &GetCurrentUserGuildsErrorType {
         &self.kind
     }
 
@@ -146,13 +146,13 @@ impl<'a> GetCurrentUserGuilds<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.request(Request::from(
-            Route::GetGuilds {
-                after: self.fields.after.map(|x| x.0),
-                before: self.fields.before.map(|x| x.0),
-                limit: self.fields.limit,
-            },
-        ))));
+        let request = Request::from_route(Route::GetGuilds {
+            after: self.fields.after.map(|x| x.0),
+            before: self.fields.before.map(|x| x.0),
+            limit: self.fields.limit,
+        });
+
+        self.fut.replace(Box::pin(self.http.request(request)));
 
         Ok(())
     }
