@@ -18,11 +18,11 @@ impl<'a> LeaveGuild<'a> {
     }
 
     fn start(&mut self) -> Result<()> {
-        self.fut.replace(Box::pin(self.http.verify(Request::from(
-            Route::LeaveGuild {
-                guild_id: self.guild_id.0,
-            },
-        ))));
+        let request = Request::from_route(Route::LeaveGuild {
+            guild_id: self.guild_id.0,
+        });
+
+        self.fut.replace(Box::pin(self.http.verify(request)));
 
         Ok(())
     }
